/*******************************************************************************
 * Copyright (c) 2004 IBM Corporation.
 * All rights reserved. 
 *******************************************************************************/
package com.ibm.gallery.common.wizards;

import org.eclipse.core.resources.IResource;
import org.eclipse.core.resources.IWorkspace;
import org.eclipse.core.resources.ResourcesPlugin;
import org.eclipse.core.runtime.IConfigurationElement;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;

import org.eclipse.swt.SWT;
import org.eclipse.swt.events.ModifyEvent;
import org.eclipse.swt.events.ModifyListener;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;
import org.eclipse.ui.PlatformUI;

import org.eclipse.jface.dialogs.DialogPage;
import org.eclipse.jface.wizard.WizardPage;

import com.ibm.ccl.ua.wizards.*;

public class ExampleProjectCreationWizardPage extends WizardPage {

	private IStatus currStatus;
	
	private boolean pageVisible;
	
	private IConfigurationElement configElement;
	String [] natureIds;
	String [] references;
	String [] importDests;
	String [] importSrcs;
	String wizardPlugin;
	String remoteWizURL;
		
	String nameLabel;
	String projName;
	String finalPerspective;
	String wizDescription;
	String wizPageTitle;
	String wizLabel;
	String wizPageDescription;
	String projectNature;
	String projectSrc;
	String projectDest;	
	
	private Text fTextControl;
	
	public ExampleProjectCreationWizardPage(int pageNumber, IConfigurationElement elem) {
		super("page" + pageNumber); //$NON-NLS-1$
		currStatus= createStatus(IStatus.OK, ""); //$NON-NLS-1$
		
		configElement= elem;
		
		setTitle(getAttribute(elem, "pagetitle")); //$NON-NLS-1$
		setDescription(getAttribute(elem, "pagedescription")); //$NON-NLS-1$
		
		nameLabel= getAttribute(elem, "label"); //$NON-NLS-1$
		projName= getAttribute(elem, "name");	//$NON-NLS-1$
		
	}
	
	public ExampleProjectCreationWizardPage(int pageNumber, String wizardTitle,String wizardDescription,String wizFinalPerspective, String projectName, String wizardPageDescription, String wizardLabel, String wizardProjectNature, String wizardProjectSrc, String wizardProjectDest, String pluginName, String wizURL) {
		
		super("page" + pageNumber); //$NON-NLS-1$
		currStatus= createStatus(IStatus.OK, ""); //$NON-NLS-1$
		
		setTitle(wizardTitle); //$NON-NLS-1$
		setDescription(wizardDescription); //$NON-NLS-1$
		
		nameLabel= wizardTitle; //$NON-NLS-1$
		projName= projectName;	//$NON-NLS-1$
		
		finalPerspective = wizFinalPerspective;
		wizDescription=wizardDescription;
		wizPageDescription=wizardPageDescription;
		wizPageTitle=wizardLabel;
		
		projectNature=wizardProjectNature;
		projectSrc=wizardProjectSrc;
		projectDest=wizardProjectDest;
		
		wizardPlugin=pluginName;
		remoteWizURL=wizURL;
		
		buildPageArrays();
		
	}
	
	private String getAttribute(IConfigurationElement elem, String tag) {
		String res= elem.getAttribute(tag);
		if (res == null) {
			return tag;
		}
		return res;
	}
	
	/*
	 * @see IDialogPage#createControl(Composite)
	 */
	public void createControl(Composite parent) {
		// TODO: remove if not used
		PlatformUI.getWorkbench().getHelpSystem().setHelp(parent, "sgez0101"); //$NON-NLS-1$

		Composite composite= new Composite(parent, SWT.NONE);
		GridLayout gd= new GridLayout();
		gd.numColumns= 2;
		composite.setLayout(gd);
		
		Label label= new Label(composite, SWT.LEFT);
		label.setText(nameLabel);
		label.setLayoutData(new GridData());
		
		fTextControl= new Text(composite, SWT.SINGLE | SWT.BORDER);
		fTextControl.setText(projName);
		fTextControl.addModifyListener(new ModifyListener() {
			public void modifyText(ModifyEvent e) {
				if (!fTextControl.isDisposed()) {
					validateText(fTextControl.getText());
				}
			}
		});
		fTextControl.setLayoutData(new GridData(GridData.FILL_HORIZONTAL));
		
		setControl(composite);
		
	}

	private void validateText(String text) {
		IWorkspace workspace= ResourcesPlugin.getWorkspace();
		IStatus status= workspace.validateName(text, IResource.PROJECT);
		if (status.isOK()) {
			if (workspace.getRoot().getProject(text).exists()) {
				status= createStatus(IStatus.ERROR, ExampleProjectMessages.getString("ExampleProjectCreationWizardPage.error.alreadyexists")); //$NON-NLS-1$
			}
		}	
		updateStatus(status);
		
		projName= text;
	}	
	
	
	/*
	 * @see WizardPage#becomesVisible
	 */
	public void setVisible(boolean visible) {
		super.setVisible(visible);
		pageVisible= visible;
		// policy: wizards are not allowed to come up with an error message
		if (visible && currStatus.matches(IStatus.ERROR)) {
			// keep the error state, but remove the message
			currStatus= createStatus(IStatus.ERROR, ""); //$NON-NLS-1$
		} 
		updateStatus(currStatus);
	}	

	/**
	 * Updates the status line and the ok button depending on the status
	 */
	private void updateStatus(IStatus status) {
		currStatus = status;
		setPageComplete(!status.matches(IStatus.ERROR));
		if (pageVisible) {
			applyToStatusLine(this, status);
		}
	}

	/**
	 * Applies the status to a dialog page
	 */
	private static void applyToStatusLine(DialogPage page, IStatus status) {
		String errorMessage= null;
		String warningMessage= null;
		String statusMessage= status.getMessage();
		if (statusMessage.length() > 0) {
			if (status.matches(IStatus.ERROR)) {
				errorMessage= statusMessage;
			} else if (!status.isOK()) {
				warningMessage= statusMessage;
			}
		}
		page.setErrorMessage(errorMessage);
		page.setMessage(warningMessage);
	}
	
	
	private static IStatus createStatus(int severity, String message) {
		return new Status(severity, Activator.PLUGIN_ID, severity, message, null);
	}
	
	/**
	 * Returns the name entered by the user
	 */
	public String getName() {
		return projName;
	}

	/**
	 * Returns the configuration element of this page.
	 * @return Returns a IConfigurationElement
	 */
	public IConfigurationElement getConfigurationElement() {
		return configElement;
	}
	
	public void buildPageArrays()
	{
		natureIds=projectNature.split(",");
		references=new String[0];
		importDests= projectDest.split(",");
		importSrcs= projectSrc.split(",");
	}

}

